@@ -29,17 +29,18 @@ from ._minimal_meme_output import MinimalMemeOutput
 from cookbook.named_tuple import namedtuple
 from cookbook.timer import SimpleTimer, Timer
 from cookbook.interval import Interval
-from cookbook.script_basics import log_exception, setup_logging
 from cookbook.pylab_utils import pylab_ioff, pylab_context_ioff
 
-import glob, os, math, numpy as N, itertools, time, subprocess, pylab as P, copy, warnings
+import glob, os, math, numpy as N, itertools, time, subprocess, pylab as P, warnings
 from optparse import OptionParser, OptionGroup
-from itertools import imap, chain
+from itertools import imap
 from collections import defaultdict
 
 logger = logging.getLogger(__name__)
-logging.captureWarnings(True)
-
+try:
+    logging.captureWarnings(True)
+except AttributeError:
+    warnings.warn('Could not ask logging system to capture warnings. Old logging module?')
 
 
 def add_options(option_parser):
@@ -734,11 +735,14 @@ InstanceInfo = namedtuple('InstanceInfo', 'instance seqname seq pos wmer score p
 def instance_info(instance, data, ids, W, scaled_log_odds=None, pssm_cdf=None):
     """Returns a tuple of information about the instance.
     """
+    logger.debug('Getting local position: %d', instance.global_pos)
     seq, pos = data.pos_localise(instance.global_pos)
+    logger.debug('Getting W-mer: %d %d', W, instance.global_pos)
     wmer = data.get_W_mer(W, instance.global_pos)
     if instance.rev_comp:
         wmer = reverse_complement(wmer)
     if None != scaled_log_odds and None != pssm_cdf:
+        logger.debug('Scoring W-mer: %s', wmer)
         score = score_pssm_on_seq(scaled_log_odds, imap(index_for_base, wmer))
         pvalue = pssm_cdf[score]
     else:
@@ -807,19 +811,6 @@ def read_sequences(fasta_file, options):
     num_bases, seqs, ids = read_fasta(fasta_file)
     logger.info('Read %d bases from %d sequences in %s', num_bases, len(seqs), fasta_file)
     index = build_index(seqs)
-    try:
-        if not options.max_num_sites:
-            # allow number of sites up to 3 * # sequences / 2, with hard limit of 10000 if not user-specified
-            hard_limit = 10000
-            options.max_num_sites = min(3 * len(seqs) / 2, hard_limit)
-            if hard_limit == options.max_num_sites:
-                logger.warning('Hit cap of %d on maximum # sites, user can over-ride this with the --max-sites option. High values will slow STEME down.' % hard_limit)
-            logger.info('Set maximum number of sites to %d', options.max_num_sites)
-        if not options.min_num_sites:
-            options.min_num_sites = max(len(seqs) / 10, 2) # always look for at least 2 sites
-            logger.info('Set minimum number of sites to %d', options.min_num_sites)
-    except AttributeError:
-        pass # ignore options that do not have max_num_sites
     return num_bases, seqs, ids, index
 
 
@@ -1278,12 +1269,14 @@ class MotifFinder(object):
         motif_idx,
         bg_freqs,
         options,
-        bg_sequences = None
+        bg_sequences = None,
+        bg_bg_manager = None
     ):
         self.input_sequences = input_sequences
         "The input_sequences we are finding the motif in."
         
         self.bg_manager = bg_manager
+        self.bg_bg_manager = bg_bg_manager
         
         self.significance = significance
         "Calculates the significance of motifs."
@@ -1506,6 +1499,12 @@ class MotifFinder(object):
         instances = InstanceVec()
         instances.extend(best_w_mer_finder.best_w_mers[:num_sites_to_use])
         sort_instances_by_position(instances)
+#        logging.info('Best W-mers from start:')
+#        for instance in start.best_w_mers:
+#            logging.info('%6d %f %s', instance.global_pos, instance.Z, instance.rev_comp and '-' or '+')
+#        logging.info('Instances:')
+#        for instance in instances:
+#            logging.info('%6d %f %s', instance.global_pos, instance.Z, instance.rev_comp and '-' or '+')
         overlap, start_size, _discretized_size = compare_instances(start.best_w_mers, start.model.W, instances, start.model.W)
         coverage = start_size and overlap / float(start_size) or 1.
         StartingPointFinder.log_start(
@@ -1636,7 +1635,7 @@ class MotifFinder(object):
                     
         logger.info('Ran EM on %d starts', len(start_results))
         self._plot_num_sites_graph(start_results)
-        self._plot_coverage_vs_E_value(start_results) # don't plot as sometimes causes exception (need to investigate)
+        self._plot_coverage_vs_E_value(start_results)
         
         
         #
@@ -1696,7 +1695,7 @@ class MotifFinder(object):
         #
         bg_stats = None
         if self.bg_sequences:
-            bg_prediction_model = self.bg_sequences.create_model(self.bg_manager.get_bg_model(best_model.W), best_model.W)
+            bg_prediction_model = self.bg_sequences.create_model(self.bg_bg_manager.get_bg_model(best_model.W), best_model.W)
             bg_prediction_model.bs.pssm.log_probs.values()[:] = best_model.bs.pssm.log_probs.values()
             bg_prediction_model.bs.recalculate()
             bg_prediction_model.lambda_ = best_model.lambda_
@@ -1889,7 +1888,7 @@ class LogLikelihoodBgModelManager(BgModelManager):
         Return a background model of the sequences for the specified width.
         """
         if W not in self.bg_models:
-            logging.info("Creating background model for W=%d", W)
+            logger.info("Creating background model for W=%d", W)
             self.bg_models[W] = create_bg_model_from_base_likelihoods(
                 W, self.sequences.data, 
                 self.lls, 
@@ -2028,6 +2027,16 @@ class Algorithm(object):
     def _load_sequences(self, fasta):
         "Read the sequences and build STEME object from index."
         self.input_sequences = SequenceSet(fasta, self.options)
+        if not self.options.max_num_sites:
+            # allow number of sites up to 3 * # sequences / 2, with hard limit of 10000 if not user-specified
+            hard_limit = 10000
+            self.options.max_num_sites = min(3 * len(self.input_sequences.seqs) / 2, hard_limit)
+            if hard_limit == self.options.max_num_sites:
+                logger.warning('Hit cap of %d on maximum # sites, user can over-ride this with the --max-sites option. High values will slow STEME down.' % hard_limit)
+            logger.info('Set maximum number of sites to %d', self.options.max_num_sites)
+        if not self.options.min_num_sites:
+            self.options.min_num_sites = max(len(self.input_sequences.seqs) / 10, 2) # always look for at least 2 sites
+            logger.info('Set minimum number of sites to %d', self.options.min_num_sites)
         
         
     def _initialise_bg(self):
@@ -2040,12 +2049,14 @@ class Algorithm(object):
             logger.info('Building background Markov model from sequences in %s', self.options.bg_fasta_file)
             self.bg_sequences = SequenceSet(self.options.bg_fasta_file, self.options)
             self.bg_manager = get_background_manager(self.input_sequences, self.bg_sequences.mm, self.options)
+            self.bg_bg_manager = get_background_manager(self.bg_sequences, self.bg_sequences.mm, self.options)
             self.freqs = self.bg_sequences.freqs
             self.freqs_with_pseudo_counts = self.bg_sequences.freqs_with_pseudo_counts
         else:
             # no, build background model from sequences we are searching for motifs in
             logger.info('Building background Markov model from input sequences')
             self.bg_manager = get_background_manager(self.input_sequences, self.input_sequences.mm, self.options)
+            self.bg_bg_manager = None
             self.freqs = self.input_sequences.freqs
             self.freqs_with_pseudo_counts = self.input_sequences.freqs_with_pseudo_counts
         
@@ -2083,7 +2094,8 @@ class Algorithm(object):
             motif_idx,
             self.input_sequences.get_bg_freqs(),
             self.options,
-            self.bg_sequences
+            self.bg_sequences,
+            self.bg_bg_manager
         )
     
     
