@@ -30,7 +30,7 @@ algorithm = stempy.Algorithm(options)
 algorithm._initialise(fasta)
 motif_finder = algorithm.create_motif_finder()
 
-model = algorithm.input_sequences.create_model(W)
+model = algorithm.create_model_of_input(W)
 model.bs.seed(seed, True)
 start = Start(seed=seed, num_sites=10, score=0., model=model, best_w_mers=stempy.InstanceVec())
 em_result = motif_finder._run_em_from_start(start, return_EM=True)
